Support
=======

ZTPServer is an Arista led open source community project.  Users and developers are encouraged to contribute to the project.  See `CONTRIBUTING.md <https://github.com/arista-eosplus/ztpserver/blob/develop/CONTRIBUTING.md>`_ in the source for more information on how.

Community based support is available through 

* `eosplus forum <https://groups.google.com/forum/#!forum/eosplus>`_
* eosplus-dev@arista.com.
* IRC: irc.freenode.net#arista

Commercial support, customization, and integration services are available through the EOS+ team at `Arista Networks, Inc. <http://arista.com/>`_.  Contact eosplus-dev@arista.com for details.

